@@ -17,24 +17,24 @@ function(x,digits = max(3, getOption("digits") - 3),...)
     cat("was fit by probit")
 
   cat("\nCoefficients:\n") 
-  print.matrix(x$coefficients[1:x$kz,],
-                digits = digits, 
-                ...)
+  print(x$coefficients[1:x$kz,],
+        digits = digits, 
+        ...)
 
   if(x$dist=="poisson"){
     cat("\n\nCount Model for Non-Zero Outcomes (Poisson)\n")
     cat("Coefficients:\n")
-    print.matrix(x$coefficients[(x$kz+1):(x$kz+x$kx),],
-                 digits = digits,
-                  ...)
+    print(x$coefficients[(x$kz+1):(x$kz+x$kx),],
+          digits = digits,
+          ...)
   }
 
   if(x$dist=="negbin"){
     cat("\n\nCount Model for Non-Zero Outcomes (Negative Binomial)\n")
     cat("Coefficients:\n")
-    print.matrix(x$coefficients[(x$kz+1):(x$kz+x$kx+1),],
-                  digits = digits,
-                  ...)
+    print(x$coefficients[(x$kz+1):(x$kz+x$kx+1),],
+          digits = digits,
+          ...)
   }
   invisible(NULL)
 }
